function are_the_same = compare_strings(first_string, second_string)
%
% Compare the two strings given as arguments.  If the same, return 1.
% If different, return 0.
% 
% Arguments:
%               first_string       (input)   compare this string ...
%               second_string      (input)   ... to this one
%               are_the_same      (output)   set to 1 if they are identical,
%                                                   0 if they differ
%                                                  
% MWR 4/11/2001

  if (strcmp(first_string, second_string) == 0)
    are_the_same = 0;
  else
    are_the_same = 1;
  end

